# Memory Buffer

With use or Memory buffer you get access to past images.

- On/Off checkbox - switches on or off buffering of the images
- Size - number of images in the circular memory buffer. Its green background means that the buffer is full and new images with overwrite the old ones
- Reset - reset content o the buffer

Earlier images can be selected in the Channel widget. The user can select also there a sum or mean of all buffer images or an RGB view.